/*
 * rpmlist.c
 *
 * (C) Copyright IBM Corp. 2002
 *
 * THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE 
 * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE 
 * CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
 *
 * You can obtain a current copy of the Common Public License from
 * http://oss.software.ibm.com/developerworks/opensource/license-cpl.html
 *
 * Author: Viktor Mihajlovski <mihajlov@de.ibm.com>
 * Contributors:
 *
 * Description: CIM RPM Library Test Program
 */

#include <stdio.h>
#include <stdlib.h>
#include "cimrpm.h"

int main(int argc, char * argv[])
{
  HCRPM hcrpm;
  CRPM_SE crpmse;
  char ** files;

  if (argc!=2) {
    fprintf(stderr,"usage: %s pkgspec\n",argv[0]);
    exit(-1);
  }

  hcrpm=CRPM_Init();

  if (hcrpm==NULL) {
    fprintf(stderr,"error initializing...quit now\n");
    exit(-1);
  }
  
  if (argv[1][0] != '*')
    if (!CRPM_SinglePkgEnum(hcrpm,argv[1],&crpmse)) {
      printf("<%s %s %s %d %d>: %s %s\n", 
	     crpmse.seId, 
	     crpmse.seName, 
	     crpmse.seVersion, 
	     crpmse.seState, 
	     crpmse.seOs, 
	     crpmse.seManufacturer, 
	     crpmse.seInstalled);
      files=CRPM_SinglePkgFiles(hcrpm,argv[1],&crpmse);
      while (files && *files)
	printf("\t%s\n",*files++);
    }
    else
      printf("Package <%s> not found\n",argv[1]);
  else {
    if (CRPM_InitPkgEnum(hcrpm,&crpmse) < 0) {
      fprintf(stderr,"could not start enumeration\n");
      exit(1);
    }
    
    while (CRPM_NextPkgEnum(&crpmse)) {
      printf("<%s %s %s %d %d>: %s %s\n", 
	     crpmse.seId, 
	     crpmse.seName, 
	     crpmse.seVersion, 
	     crpmse.seState, 
	     crpmse.seOs, 
	     crpmse.seManufacturer, 
	     crpmse.seInstalled);	     
    } 
  }

  CRPM_TermPkgEnum(&crpmse);  
  CRPM_Term(hcrpm);
  
  return 0;
}
